pub struct CUIntentSend {
pub ttl: Option<u64>,
pub email: Option<String>,
}Expand description
Structure denoting the parameters for triggering a credential update intent token to be send to the account.
Fields
ttl: Option<u64>email: Option<String>Trait Implementations
Sourceimpl ComposeSchema for CUIntentSend
impl ComposeSchema for CUIntentSend
Sourceimpl Debug for CUIntentSend
impl Debug for CUIntentSend
Sourceimpl<'de> Deserialize<'de> for CUIntentSend
impl<'de> Deserialize<'de> for CUIntentSend
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for CUIntentSend
impl Serialize for CUIntentSend