pub enum Prompt {
None,
Login,
Consent,
SelectAccount,
Invalid(String),
}Variants
None
None is not the absence of a value but a rather a value itself. Prompt::None signifies to kanidm that if the authentications server cannot automatically proceed thanks to an already logged in user, It must return a error response rather than allowing a user to proceed through the regular login flow.
This is specified in OIDC Core 1.0 3.1.2.1 https://openid.net/specs/openid-connect-core-1_0.html
Login
Consent
SelectAccount
Invalid(String)